package javax.swing;

import java.awt.AWTEvent;
import java.awt.KeyEventDispatcher;
import java.beans.VetoableChangeListener;
import java.beans.PropertyChangeListener;
import java.awt.Container;
import java.awt.AWTKeyStroke;
import java.util.Set;
import java.awt.FocusTraversalPolicy;
import java.awt.Window;
import java.awt.event.KeyEvent;
import java.awt.Component;
import java.awt.KeyboardFocusManager;

final class DelegatingDefaultFocusManager extends DefaultFocusManager
{
    private final KeyboardFocusManager delegate;
    
    DelegatingDefaultFocusManager(KeyboardFocusManager delegate) {
        this.delegate = delegate;
        this.setDefaultFocusTraversalPolicy(this.gluePolicy);
    }
    
    KeyboardFocusManager getDelegate() {
        return this.delegate;
    }
    
    @Override
    public void processKeyEvent(Component component, KeyEvent keyEvent) {
        this.delegate.processKeyEvent(component, keyEvent);
    }
    
    @Override
    public void focusNextComponent(Component component) {
        this.delegate.focusNextComponent(component);
    }
    
    @Override
    public void focusPreviousComponent(Component component) {
        this.delegate.focusPreviousComponent(component);
    }
    
    @Override
    public Component getFocusOwner() {
        return this.delegate.getFocusOwner();
    }
    
    @Override
    public void clearGlobalFocusOwner() {
        this.delegate.clearGlobalFocusOwner();
    }
    
    @Override
    public Component getPermanentFocusOwner() {
        return this.delegate.getPermanentFocusOwner();
    }
    
    @Override
    public Window getFocusedWindow() {
        return this.delegate.getFocusedWindow();
    }
    
    @Override
    public Window getActiveWindow() {
        return this.delegate.getActiveWindow();
    }
    
    @Override
    public FocusTraversalPolicy getDefaultFocusTraversalPolicy() {
        return this.delegate.getDefaultFocusTraversalPolicy();
    }
    
    @Override
    public void setDefaultFocusTraversalPolicy(FocusTraversalPolicy defaultFocusTraversalPolicy) {
        if (this.delegate != null) {
            this.delegate.setDefaultFocusTraversalPolicy(defaultFocusTraversalPolicy);
        }
    }
    
    @Override
    public void setDefaultFocusTraversalKeys(int id, Set<? extends AWTKeyStroke> keystrokes) {
        this.delegate.setDefaultFocusTraversalKeys(id, keystrokes);
    }
    
    @Override
    public Set<AWTKeyStroke> getDefaultFocusTraversalKeys(int id) {
        return this.delegate.getDefaultFocusTraversalKeys(id);
    }
    
    @Override
    public Container getCurrentFocusCycleRoot() {
        return this.delegate.getCurrentFocusCycleRoot();
    }
    
    @Override
    public void setGlobalCurrentFocusCycleRoot(Container globalCurrentFocusCycleRoot) {
        this.delegate.setGlobalCurrentFocusCycleRoot(globalCurrentFocusCycleRoot);
    }
    
    @Override
    public void addPropertyChangeListener(PropertyChangeListener listener) {
        this.delegate.addPropertyChangeListener(listener);
    }
    
    @Override
    public void removePropertyChangeListener(PropertyChangeListener listener) {
        this.delegate.removePropertyChangeListener(listener);
    }
    
    @Override
    public void addPropertyChangeListener(String propertyName, PropertyChangeListener listener) {
        this.delegate.addPropertyChangeListener(propertyName, listener);
    }
    
    @Override
    public void removePropertyChangeListener(String propertyName, PropertyChangeListener listener) {
        this.delegate.removePropertyChangeListener(propertyName, listener);
    }
    
    @Override
    public void addVetoableChangeListener(VetoableChangeListener listener) {
        this.delegate.addVetoableChangeListener(listener);
    }
    
    @Override
    public void removeVetoableChangeListener(VetoableChangeListener listener) {
        this.delegate.removeVetoableChangeListener(listener);
    }
    
    @Override
    public void addVetoableChangeListener(String propertyName, VetoableChangeListener listener) {
        this.delegate.addVetoableChangeListener(propertyName, listener);
    }
    
    @Override
    public void removeVetoableChangeListener(String propertyName, VetoableChangeListener listener) {
        this.delegate.removeVetoableChangeListener(propertyName, listener);
    }
    
    @Override
    public void addKeyEventDispatcher(KeyEventDispatcher dispatcher) {
        this.delegate.addKeyEventDispatcher(dispatcher);
    }
    
    @Override
    public void removeKeyEventDispatcher(KeyEventDispatcher dispatcher) {
        this.delegate.removeKeyEventDispatcher(dispatcher);
    }
    
    @Override
    public boolean dispatchEvent(AWTEvent awtEvent) {
        return this.delegate.dispatchEvent(awtEvent);
    }
    
    @Override
    public boolean dispatchKeyEvent(KeyEvent keyEvent) {
        return this.delegate.dispatchKeyEvent(keyEvent);
    }
    
    @Override
    public void upFocusCycle(Component component) {
        this.delegate.upFocusCycle(component);
    }
    
    @Override
    public void downFocusCycle(Container container) {
        this.delegate.downFocusCycle(container);
    }
}
